Technology
==========

.. list-table::
   :header-rows: 1

   * - Project’s part
     - Technology

   * - Language
     - Python 3.x

   * - Framework
     - Django 1.8.x

   * - Database
     - SQLite 3 [#f1]_

   * - Front-end
     - HTML, CSS, JS framework like Bootstrap or Pure CSS 

   * - Documentation
     - `Sphinx <http://sphinx-doc.org/>`_

Also used third-party components:

#. `JSColor <http://jscolor.com/>`_  as color picker in admin
#. `Bootstrap <http://getbootstrap.com/>`_, `Pure CSS <http://purecss.io/>`_ into :ref:`themes <Themes>`.

.. rubric:: Footnotes

.. [#f1] Optionally, you can use MySql, see :ref:`faq`.
